public inbox for cluster-cvs@sourceware.org
help / color / mirror / Atom feed
* cluster: RHEL54 - Revert "gfs-kernel: bz487610 - Change gfs freeze/unfreeze to use new standard"
@ 2009-06-02 15:45 Chris Feist
  0 siblings, 0 replies; only message in thread
From: Chris Feist @ 2009-06-02 15:45 UTC (permalink / raw)
  To: cluster-cvs-relay

Gitweb:        http://git.fedorahosted.org/git/cluster.git?p=cluster.git;a=commitdiff;h=d97ab88191384c94cfa51840f6379fcc6ecaeb89
Commit:        d97ab88191384c94cfa51840f6379fcc6ecaeb89
Parent:        0d82bd7f38bd6e898fdfd5f22c8e1a2386300745
Author:        Chris Feist <cfeist@redhat.com>
AuthorDate:    Tue Jun 2 10:42:59 2009 -0500
Committer:     Chris Feist <cfeist@redhat.com>
CommitterDate: Tue Jun 2 10:42:59 2009 -0500

Revert "gfs-kernel: bz487610 - Change gfs freeze/unfreeze to use new standard"

Reverting beause this bz is targetted for 5.5.

This reverts commit 28daa9be2045dc307701144631d118e46ed685d3.
---
 gfs-kernel/src/gfs/ops_fstype.c |    2 +-
 gfs-kernel/src/gfs/ops_super.c  |   20 +++++++++-----------
 2 files changed, 10 insertions(+), 12 deletions(-)

diff --git a/gfs-kernel/src/gfs/ops_fstype.c b/gfs-kernel/src/gfs/ops_fstype.c
index a9d7733..4f0b471 100644
--- a/gfs-kernel/src/gfs/ops_fstype.c
+++ b/gfs-kernel/src/gfs/ops_fstype.c
@@ -819,7 +819,7 @@ gfs_kill_sb(struct super_block *sb)
 
 struct file_system_type gfs_fs_type = {
 	.name = "gfs",
-	.fs_flags = FS_REQUIRES_DEV | FS_HAS_FREEZE,
+	.fs_flags = FS_REQUIRES_DEV,
 	.get_sb = gfs_get_sb,
 	.kill_sb = gfs_kill_sb,
 	.owner = THIS_MODULE,
diff --git a/gfs-kernel/src/gfs/ops_super.c b/gfs-kernel/src/gfs/ops_super.c
index fb7ee0e..7f92691 100644
--- a/gfs-kernel/src/gfs/ops_super.c
+++ b/gfs-kernel/src/gfs/ops_super.c
@@ -195,19 +195,19 @@ gfs_write_super(struct super_block *sb)
 }
 
 /**
  * gfs_freeze - prevent further writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
  */
 
-static int
-gfs_freeze(struct super_block *sb)
+static void
+gfs_write_super_lockfs(struct super_block *sb)
 {
 	struct gfs_sbd *sdp = get_v2sdp(sb);
 	int error;
 
 	if (test_bit(SDF_SHUTDOWN, &sdp->sd_flags))
-		return -EINVAL;
+		return;
 
 	atomic_inc(&sdp->sd_ops_super);
 
@@ -233,24 +233,22 @@ gfs_freeze(struct super_block *sb)
 		set_current_state(TASK_UNINTERRUPTIBLE);
 		schedule_timeout(HZ);
 	}
-	return 0;
 }
 
 /**
  * gfs_unfreeze - reallow writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
  */
 
-static int
-gfs_unfreeze(struct super_block *sb)
+static void
+gfs_unlockfs(struct super_block *sb)
 {
 	struct gfs_sbd *sdp = get_v2sdp(sb);
 
 	atomic_inc(&sdp->sd_ops_super);
 
 	gfs_unfreeze_fs(sdp);
-	return 0;
 }
 
 /**
@@ -460,8 +458,8 @@ struct super_operations gfs_super_ops = {
 	.put_inode = gfs_put_inode,
 	.put_super = gfs_put_super,
 	.write_super = gfs_write_super,
-	.freeze_fs = gfs_freeze,
-	.unfreeze_fs = gfs_unfreeze,
+	.write_super_lockfs = gfs_write_super_lockfs,
+	.unlockfs = gfs_unlockfs,
 	.statfs = gfs_statfs,
 	.remount_fs = gfs_remount_fs,
 	.clear_inode = gfs_clear_inode,


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2009-06-02 15:45 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -195,19 +195,19 @@ gfs_write_super(struct super_block *sb)
 
 /**
- * gfs_freeze - prevent further writes to the filesystem
+ * gfs_write_super_lockfs - prevent further writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
@@ -233,24 +233,22 @@ gfs_freeze(struct super_block *sb)
 
 /**
- * gfs_unfreeze - reallow writes to the filesystem
+ * gfs_unlockfs - reallow writes to the filesystem
  * @sb: the VFS structure for the filesystem
  *
2009-06-02 15:45 cluster: RHEL54 - Revert "gfs-kernel: bz487610 - Change gfs freeze/unfreeze to use new standard" Chris Feist

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).